# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from continual.rpc.management.v1 import management_pb2 as continual_dot_rpc_dot_management_dot_v1_dot_management__pb2
from continual.rpc.management.v1 import management_types_pb2 as continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ManagementAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListUsers',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.FromString,
                )
        self.BatchGetUsers = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetUsers',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.FromString,
                )
        self.UpdateUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteUser',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetViewer = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetViewer',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
                )
        self.Register = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Register',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.FromString,
                )
        self.Login = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Login',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Logout',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendEmailVerification = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/SendEmailVerification',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.VerifyEmail = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/VerifyEmail',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.FromString,
                )
        self.SendPasswordReset = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/SendPasswordReset',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ResetPassword = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ResetPassword',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.FromString,
                )
        self.GetSession = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSession',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.FromString,
                )
        self.ListSessions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListSessions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.FromString,
                )
        self.DeleteSession = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteSession',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAllSessions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteAllSessions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.BatchGetOrganizations = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetOrganizations',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListOrganizations',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.FromString,
                )
        self.CreateOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteOrganization',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOnboarding = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetOnboarding',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
                )
        self.UpdateOnboarding = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateOnboarding',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListRoles',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.FromString,
                )
        self.GetRole = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetRole',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.FromString,
                )
        self.BatchGetRoles = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetRoles',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.FromString,
                )
        self.CreateAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.GetAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.ListAccessPolicies = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListAccessPolicies',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.FromString,
                )
        self.DeleteAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateAccessPolicy = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateAccessPolicy',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
                )
        self.TestPermissions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TestPermissions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.FromString,
                )
        self.CreateInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.GetInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.ListInvites = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListInvites',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.FromString,
                )
        self.UpdateInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.ResendInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ResendInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
                )
        self.DeleteInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AcceptInvite = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/AcceptInvite',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.BatchGetProjects = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetProjects',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListProjects',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.FromString,
                )
        self.CreateProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteProject',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.TestProjectDataStore = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TestProjectDataStore',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreResponse.FromString,
                )
        self.TestDataStore = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TestDataStore',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreResponse.FromString,
                )
        self.GetSchemaGraph = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSchemaGraph',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphResponse.FromString,
                )
        self.GetFeatureSet = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetFeatureSet',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.FeatureSet.FromString,
                )
        self.BatchGetFeatureSets = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetFeatureSets',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsResponse.FromString,
                )
        self.ListFeatureSets = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListFeatureSets',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsResponse.FromString,
                )
        self.DeleteFeatureSet = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteFeatureSet',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ValidateFeatureSet = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ValidateFeatureSet',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateFeatureSetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetEntity = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEntity',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Entity.FromString,
                )
        self.ListEntities = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListEntities',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesResponse.FromString,
                )
        self.GetEntityFeatureSets = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEntityFeatureSets',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsResponse.FromString,
                )
        self.GetFeatureSetDatasetStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetFeatureSetDatasetStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetDatasetStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
                )
        self.GetModelDatasetStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelDatasetStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelDatasetStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
                )
        self.GetModelVersionDatasetStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelVersionDatasetStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionDatasetStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
                )
        self.GetBatchPredictionDatasetStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetBatchPredictionDatasetStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBatchPredictionDatasetStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
                )
        self.GetPredictionStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPredictionStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPredictionStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
                )
        self.GetFeatureSetStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetFeatureSetStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.FromString,
                )
        self.GetModelStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelStatsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.FromString,
                )
        self.ComputeColumnStats = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ComputeColumnStats',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ComputeColumnStatsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetData = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetData',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataResponse.FromString,
                )
        self.CreateFeatureSetCSVSignedURL = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateFeatureSetCSVSignedURL',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLResponse.FromString,
                )
        self.CreateChange = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateChange',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateChangeRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
                )
        self.ReRun = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ReRun',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ReRunRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
                )
        self.GetChange = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetChange',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetChangeRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
                )
        self.ListChanges = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListChanges',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesResponse.FromString,
                )
        self.CancelChange = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CancelChange',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelChangeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PromoteModelVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/PromoteModelVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.PromoteModelVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
                )
        self.ListPromotions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListPromotions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.FromString,
                )
        self.GetPromotion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPromotion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
                )
        self.BatchGetPromotions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetPromotions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.FromString,
                )
        self.ListEvents = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListEvents',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.FromString,
                )
        self.GetEvent = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEvent',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.FromString,
                )
        self.BatchGetEvents = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetEvents',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.FromString,
                )
        self.GetSubscription = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSubscription',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
                )
        self.GetBillingAccount = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetBillingAccount',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
                )
        self.GetUsage = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUsage',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.FromString,
                )
        self.ListInvoices = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListInvoices',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.FromString,
                )
        self.UpdateBillingAccount = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateBillingAccount',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
                )
        self.UpdateSubscription = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateSubscription',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
                )
        self.ListPrices = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListPrices',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.FromString,
                )
        self.GetPrice = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPrice',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.FromString,
                )
        self.GetPaymentMethod = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetPaymentMethod',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.FromString,
                )
        self.GetUpcomingInvoice = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetUpcomingInvoice',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.FromString,
                )
        self.GetInferredSchema = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetInferredSchema',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaResponse.FromString,
                )
        self.GetServingData = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetServingData',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataResponse.FromString,
                )
        self.GetTrainingData = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetTrainingData',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataResponse.FromString,
                )
        self.BrowseDataWarehouse = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BrowseDataWarehouse',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseResponse.FromString,
                )
        self.Seed = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/Seed',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedResponse.FromString,
                )
        self.GetModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
                )
        self.BatchGetModels = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetModels',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListModels',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.FromString,
                )
        self.DeleteModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ValidateModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ValidateModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetModelQuery = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelQuery',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryResponse.FromString,
                )
        self.GetModelVersion = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelVersion',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
                )
        self.GetModelVersionQuery = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetModelVersionQuery',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryResponse.FromString,
                )
        self.BatchGetModelVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetModelVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.FromString,
                )
        self.ListModelVersions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListModelVersions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.FromString,
                )
        self.TrainModel = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TrainModel',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TrainModelRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
                )
        self.CancelTraining = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CancelTraining',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelTrainingRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.BatchPredict = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchPredict',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
                )
        self.GetBatchPrediction = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetBatchPrediction',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
                )
        self.BatchGetBatchPredictions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetBatchPredictions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.FromString,
                )
        self.ListBatchPredictions = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListBatchPredictions',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.FromString,
                )
        self.CancelBatchPrediction = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CancelBatchPrediction',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetTrainingMetrics = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetTrainingMetrics',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsResponse.FromString,
                )
        self.ListTrainingMetrics = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListTrainingMetrics',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsResponse.FromString,
                )
        self.GetExperiment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetExperiment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
                )
        self.BatchGetExperiments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetExperiments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.FromString,
                )
        self.ListExperiments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListExperiments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.FromString,
                )
        self.GetYamlDiff = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetYamlDiff',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffResponse.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.BatchGetEnvironments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/BatchGetEnvironments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.FromString,
                )
        self.ListEnvironments = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/ListEnvironments',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.FromString,
                )
        self.CreateEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/CreateEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.UpdateEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/UpdateEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
                )
        self.DeleteEnvironment = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/DeleteEnvironment',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.TestEnvironmentDataStore = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/TestEnvironmentDataStore',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreResponse.FromString,
                )
        self.GetSystemMessage = channel.unary_unary(
                '/continual.rpc.management.v1.ManagementAPI/GetSystemMessage',
                request_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.SerializeToString,
                response_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.FromString,
                )


class ManagementAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUser(self, request, context):
        """USERS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetViewer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendEmailVerification(self, request, context):
        """EMAIL VERIFICATION

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPasswordReset(self, request, context):
        """PASSWORD RESETS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetPassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """SESSIONS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAllSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """ORGANIZATIONS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnboarding(self, request, context):
        """Onboarding

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOnboarding(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """IAM / ACCESS MANAGEMENT

        List all all roles.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRole(self, request, context):
        """Get details about a role, such as as the permissions granted.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccessPolicy(self, request, context):
        """Sets the access control policy of a subject on a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccessPolicy(self, request, context):
        """Gets the access control policy.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessPolicies(self, request, context):
        """Lists the access control policies for a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccessPolicy(self, request, context):
        """Delete the access control policy for a subject on a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestPermissions(self, request, context):
        """Returns permissions that a caller has on the specified resource.
        If the resource does not exist, this will return an empty set of
        permissions, not a NOT_FOUND error.

        Note: This operation is designed to be used for building permission-aware
        UIs and command-line tools, not for authorization checking.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInvite(self, request, context):
        """Invites

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInvites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcceptInvite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """PROJECTS

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestProjectDataStore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestDataStore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchemaGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSet(self, request, context):
        """FEATURE SETS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateFeatureSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEntities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntityFeatureSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetDatasetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDatasetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelVersionDatasetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchPredictionDatasetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPredictionStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureSetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelStats(self, request, context):
        """have specific get stats calls so graphql can connect parents.  not sure if there's a better way
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ComputeColumnStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureSetCSVSignedURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateChange(self, request, context):
        """Change
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListChanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelChange(self, request, context):
        """CancelChange cancels an change workflow.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PromoteModelVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPromotions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromotion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetPromotions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvents(self, request, context):
        """Events 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubscription(self, request, context):
        """Billing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBillingAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInvoices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBillingAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSubscription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPrices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPrice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaymentMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUpcomingInvoice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInferredSchema(self, request, context):
        """GetInferredSchema returns an inferred schema from a file or query.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServingData(self, request, context):
        """GetServingData returns data from featurestore with overrides.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrainingData(self, request, context):
        """GetTrainingData returns data from featurestore with overrides.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BrowseDataWarehouse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Seed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModel(self, request, context):
        """MODELS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelVersion(self, request, context):
        """MODEL VERSIONS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelVersionQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModelVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TrainModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelTraining(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchPredict(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetBatchPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBatchPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrainingMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTrainingMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExperiment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetExperiments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExperiments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetYamlDiff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """ENVIRONMENTS

        option (google.api.http) = {
        get : "/v1/{name=projects/*}"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetEnvironments(self, request, context):
        """option (google.api.http) = {
        get : "/v1/projects:batchGet"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironment(self, request, context):
        """option (google.api.http) = {
        post : "/v1/projects"
        body : "project"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironment(self, request, context):
        """option (google.api.http) = {
        patch : "/v1/{project.name=projects/*}"
        body : "project"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironment(self, request, context):
        """option (google.api.http) = {
        delete : "/v1/{name=projects/*}"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestEnvironmentDataStore(self, request, context):
        """option (google.api.http) = {
        post : "/v1/{name=projects/*}:testDataStore"
        };
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSystemMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ManagementAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.SerializeToString,
            ),
            'BatchGetUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetUsers,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetViewer': grpc.unary_unary_rpc_method_handler(
                    servicer.GetViewer,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.SerializeToString,
            ),
            'Register': grpc.unary_unary_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendEmailVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendEmailVerification,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'VerifyEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyEmail,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.SerializeToString,
            ),
            'SendPasswordReset': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPasswordReset,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ResetPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetPassword,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAllSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAllSessions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'BatchGetOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetOrganizations,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOnboarding': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnboarding,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.SerializeToString,
            ),
            'UpdateOnboarding': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOnboarding,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.SerializeToString,
            ),
            'GetRole': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRole,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.SerializeToString,
            ),
            'BatchGetRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetRoles,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.SerializeToString,
            ),
            'CreateAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'GetAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'ListAccessPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessPolicies,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.SerializeToString,
            ),
            'DeleteAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateAccessPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessPolicy,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.SerializeToString,
            ),
            'TestPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.TestPermissions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.SerializeToString,
            ),
            'CreateInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'GetInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'ListInvites': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInvites,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.SerializeToString,
            ),
            'UpdateInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'ResendInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.SerializeToString,
            ),
            'DeleteInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AcceptInvite': grpc.unary_unary_rpc_method_handler(
                    servicer.AcceptInvite,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'BatchGetProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetProjects,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.SerializeToString,
            ),
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'TestProjectDataStore': grpc.unary_unary_rpc_method_handler(
                    servicer.TestProjectDataStore,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreResponse.SerializeToString,
            ),
            'TestDataStore': grpc.unary_unary_rpc_method_handler(
                    servicer.TestDataStore,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreResponse.SerializeToString,
            ),
            'GetSchemaGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchemaGraph,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphResponse.SerializeToString,
            ),
            'GetFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSet,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.FeatureSet.SerializeToString,
            ),
            'BatchGetFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetFeatureSets,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsResponse.SerializeToString,
            ),
            'ListFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSets,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsResponse.SerializeToString,
            ),
            'DeleteFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureSet,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ValidateFeatureSet': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateFeatureSet,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateFeatureSetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntity,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Entity.SerializeToString,
            ),
            'ListEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEntities,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesResponse.SerializeToString,
            ),
            'GetEntityFeatureSets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntityFeatureSets,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsResponse.SerializeToString,
            ),
            'GetFeatureSetDatasetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetDatasetStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetDatasetStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.SerializeToString,
            ),
            'GetModelDatasetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDatasetStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelDatasetStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.SerializeToString,
            ),
            'GetModelVersionDatasetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelVersionDatasetStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionDatasetStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.SerializeToString,
            ),
            'GetBatchPredictionDatasetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchPredictionDatasetStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBatchPredictionDatasetStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.SerializeToString,
            ),
            'GetPredictionStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPredictionStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPredictionStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.SerializeToString,
            ),
            'GetFeatureSetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureSetStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.SerializeToString,
            ),
            'GetModelStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelStatsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.SerializeToString,
            ),
            'ComputeColumnStats': grpc.unary_unary_rpc_method_handler(
                    servicer.ComputeColumnStats,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ComputeColumnStatsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetData,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataResponse.SerializeToString,
            ),
            'CreateFeatureSetCSVSignedURL': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureSetCSVSignedURL,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLResponse.SerializeToString,
            ),
            'CreateChange': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateChange,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateChangeRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.SerializeToString,
            ),
            'ReRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ReRun,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ReRunRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.SerializeToString,
            ),
            'GetChange': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChange,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetChangeRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.SerializeToString,
            ),
            'ListChanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListChanges,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesResponse.SerializeToString,
            ),
            'CancelChange': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelChange,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelChangeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PromoteModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.PromoteModelVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.PromoteModelVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.SerializeToString,
            ),
            'ListPromotions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPromotions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.SerializeToString,
            ),
            'GetPromotion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromotion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.SerializeToString,
            ),
            'BatchGetPromotions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetPromotions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.SerializeToString,
            ),
            'ListEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvents,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.SerializeToString,
            ),
            'GetEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvent,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.SerializeToString,
            ),
            'BatchGetEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetEvents,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.SerializeToString,
            ),
            'GetSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubscription,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.SerializeToString,
            ),
            'GetBillingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBillingAccount,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.SerializeToString,
            ),
            'GetUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsage,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.SerializeToString,
            ),
            'ListInvoices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInvoices,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.SerializeToString,
            ),
            'UpdateBillingAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBillingAccount,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.SerializeToString,
            ),
            'UpdateSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSubscription,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.SerializeToString,
            ),
            'ListPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPrices,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.SerializeToString,
            ),
            'GetPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPrice,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.SerializeToString,
            ),
            'GetPaymentMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaymentMethod,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.SerializeToString,
            ),
            'GetUpcomingInvoice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUpcomingInvoice,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.SerializeToString,
            ),
            'GetInferredSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInferredSchema,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaResponse.SerializeToString,
            ),
            'GetServingData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServingData,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataResponse.SerializeToString,
            ),
            'GetTrainingData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrainingData,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataResponse.SerializeToString,
            ),
            'BrowseDataWarehouse': grpc.unary_unary_rpc_method_handler(
                    servicer.BrowseDataWarehouse,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseResponse.SerializeToString,
            ),
            'Seed': grpc.unary_unary_rpc_method_handler(
                    servicer.Seed,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedResponse.SerializeToString,
            ),
            'GetModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.SerializeToString,
            ),
            'BatchGetModels': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetModels,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.SerializeToString,
            ),
            'DeleteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ValidateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetModelQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelQuery,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryResponse.SerializeToString,
            ),
            'GetModelVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelVersion,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.SerializeToString,
            ),
            'GetModelVersionQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelVersionQuery,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryResponse.SerializeToString,
            ),
            'BatchGetModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetModelVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.SerializeToString,
            ),
            'ListModelVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelVersions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.SerializeToString,
            ),
            'TrainModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TrainModel,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TrainModelRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.SerializeToString,
            ),
            'CancelTraining': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelTraining,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelTrainingRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchPredict': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchPredict,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.SerializeToString,
            ),
            'GetBatchPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchPrediction,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.SerializeToString,
            ),
            'BatchGetBatchPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetBatchPredictions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.SerializeToString,
            ),
            'ListBatchPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchPredictions,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.SerializeToString,
            ),
            'CancelBatchPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBatchPrediction,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetTrainingMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrainingMetrics,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsResponse.SerializeToString,
            ),
            'ListTrainingMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTrainingMetrics,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsResponse.SerializeToString,
            ),
            'GetExperiment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExperiment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.SerializeToString,
            ),
            'BatchGetExperiments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetExperiments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.SerializeToString,
            ),
            'ListExperiments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExperiments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.SerializeToString,
            ),
            'GetYamlDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.GetYamlDiff,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffResponse.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'BatchGetEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetEnvironments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'UpdateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.SerializeToString,
            ),
            'DeleteEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironment,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'TestEnvironmentDataStore': grpc.unary_unary_rpc_method_handler(
                    servicer.TestEnvironmentDataStore,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreResponse.SerializeToString,
            ),
            'GetSystemMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemMessage,
                    request_deserializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.FromString,
                    response_serializer=continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'continual.rpc.management.v1.ManagementAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ManagementAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUserRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListUsers',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetUsers',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateUserRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteUser',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteUserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetViewer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetViewer',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Register',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.RegisterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Login',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Logout',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendEmailVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/SendEmailVerification',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendEmailVerificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/VerifyEmail',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.VerifyEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendPasswordReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/SendPasswordReset',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SendPasswordResetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ResetPassword',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResetPasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSession',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSessionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListSessions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteSession',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteSessionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAllSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteAllSessions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAllSessionsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetOrganizations',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListOrganizations',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOrganizationRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Organization.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteOrganization',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteOrganizationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnboarding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetOnboarding',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetOnboardingRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOnboarding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateOnboarding',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateOnboardingRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Onboarding.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListRoles',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetRole',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetRoleRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Role.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetRoles',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListAccessPolicies',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListAccessPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteAccessPolicyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateAccessPolicy',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateAccessPolicyRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.AccessPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TestPermissions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInvites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListInvites',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvitesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ResendInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ResendInviteRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invite.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteInviteRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AcceptInvite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/AcceptInvite',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.AcceptInviteRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetProjects',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListProjects',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateProjectRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteProject',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteProjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestProjectDataStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TestProjectDataStore',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestProjectDataStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestDataStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TestDataStore',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestDataStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchemaGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSchemaGraph',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSchemaGraphResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetFeatureSet',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.FeatureSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetFeatureSets',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListFeatureSets',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteFeatureSet',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateFeatureSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ValidateFeatureSet',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateFeatureSetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEntity',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Entity.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListEntities',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEntitiesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEntityFeatureSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEntityFeatureSets',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEntityFeatureSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetDatasetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetFeatureSetDatasetStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetDatasetStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDatasetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelDatasetStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelDatasetStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelVersionDatasetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelVersionDatasetStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionDatasetStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchPredictionDatasetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetBatchPredictionDatasetStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBatchPredictionDatasetStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPredictionStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPredictionStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPredictionStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.DatasetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureSetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetFeatureSetStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetFeatureSetStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelStatsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ColumnSetStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ComputeColumnStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ComputeColumnStats',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ComputeColumnStatsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetData',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureSetCSVSignedURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateFeatureSetCSVSignedURL',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateFeatureSetCSVSignedURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateChange',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateChangeRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ReRun',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ReRunRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetChange',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetChangeRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Change.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListChanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListChanges',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListChangesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CancelChange',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelChangeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PromoteModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/PromoteModelVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.PromoteModelVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPromotions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListPromotions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPromotionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromotion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPromotion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPromotionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Promotion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetPromotions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetPromotions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetPromotionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListEvents',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEvent',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEventRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Event.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetEvents',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSubscription',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSubscriptionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBillingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetBillingAccount',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetBillingAccountRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUsage',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUsageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInvoices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListInvoices',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListInvoicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBillingAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateBillingAccount',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateBillingAccountRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BillingAccount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateSubscription',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateSubscriptionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Subscription.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListPrices',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPrice',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPriceRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Price.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPaymentMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetPaymentMethod',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetPaymentMethodRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.PaymentMethod.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUpcomingInvoice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetUpcomingInvoice',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetUpcomingInvoiceRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Invoice.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInferredSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetInferredSchema',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetInferredSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServingData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetServingData',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetServingDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTrainingData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetTrainingData',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BrowseDataWarehouse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BrowseDataWarehouse',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BrowseDataWarehouseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Seed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/Seed',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.SeedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetModels',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListModels',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ValidateModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ValidateModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelQuery',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelVersion',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelVersionQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetModelVersionQuery',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetModelVersionQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetModelVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModelVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListModelVersions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListModelVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TrainModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TrainModel',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TrainModelRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.ModelVersion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelTraining(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CancelTraining',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CancelTrainingRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchPredict(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchPredict',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateBatchPredictionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetBatchPrediction',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.BatchPrediction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetBatchPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetBatchPredictions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetBatchPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBatchPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListBatchPredictions',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListBatchPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBatchPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CancelBatchPrediction',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchPredictionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTrainingMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetTrainingMetrics',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetTrainingMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTrainingMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListTrainingMetrics',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListTrainingMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExperiment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetExperiment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetExperimentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Experiment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetExperiments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetExperiments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetExperimentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExperiments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListExperiments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListExperimentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetYamlDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetYamlDiff',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.YamlDiffResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/BatchGetEnvironments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.BatchGetEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/ListEnvironments',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/CreateEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.CreateEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/UpdateEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.UpdateEnvironmentRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__types__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/DeleteEnvironment',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.DeleteEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestEnvironmentDataStore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/TestEnvironmentDataStore',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.TestEnvironmentDataStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSystemMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/continual.rpc.management.v1.ManagementAPI/GetSystemMessage',
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageRequest.SerializeToString,
            continual_dot_rpc_dot_management_dot_v1_dot_management__pb2.GetSystemMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
